# paddle-prompt

Prompt Toolkit for PaddlePaddle Deep Learning Framework. Inspired by :

* [thunlp/OpenPrompt](https://github.com/thunlp/OpenPrompt)
* [AutoPrompt](https://arxiv.org/abs/2010.15980)

***

## Installation

`paddle-prompt` is built under Python3.7+ and [Paddle](https://github.com/PaddlePaddle/Paddle). You can install `paddle-prompt` with pip:

```shell
pip install paddle-prompt
```

## TODOS

- [ ] complete PLMs
- [ ] complete template
- [ ] complete verbalizer
- [ ] create text classification datasets
- ...


## 论文复现

> 在接下来一段时间内，使用本工具可复现以下论文，如果大家想要复现其它论文，欢迎发Issue和Contribution。

- [x] [PET: Exploiting Cloze Questions for Few Shot Text Classification and Natural Language Inference](https://arxiv.org/abs/2001.07676)
- [ ] [P-Tuning: GPT Understands, Too](https://arxiv.org/pdf/2103.10385.pdf)
- [ ] [P-Tuning v2: Prompt Tuning Can Be Comparable to Fine-tuning Universally Across Scales and Tasks](https://arxiv.org/abs/2110.07602)
- [ ] [LM-BFF: Better Few-shot Fine-tuning of Language Models](https://arxiv.org/pdf/2012.15723.pdf)
- [ ] [Entailment as Few-Shot Learner](https://arxiv.org/abs/2104.14690)
- [ ] ...... more contribution


## Stargazers over time

[![Stargazers over time](https://starchart.cc/wj-Mcat/paddle-prompt.svg)](https://github.com/wj-Mcat/paddle-prompt)

## Contributors

<a href="https://github.com/wj-Mcat/paddle-prompt/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=wj-Mcat/paddle-prompt" />
</a>

Made with [contrib.rocks](https://contrib.rocks)

## Creators

- [@wj-Mcat](https://github.com/wj-Mcat) - Jingjing WU (吴京京)

## Copyright & License

- Code & Docs © 2022 wj-Mcat <https://github.com/wj-Mcat>
- Code released under the Apache-2.0 License
- Docs released under Creative Commons